summaryrefslogtreecommitdiffstatshomepage
path: root/scripts
diff options
context:
space:
mode:
Diffstat (limited to 'scripts')
-rwxr-xr-xscripts/genappimage.sh2
-rwxr-xr-xscripts/release.sh8
2 files changed, 5 insertions, 5 deletions
diff --git a/scripts/genappimage.sh b/scripts/genappimage.sh
index 29edc01950..38129d090b 100755
--- a/scripts/genappimage.sh
+++ b/scripts/genappimage.sh
@@ -16,7 +16,7 @@ ARCH_OUTPUT=$ARCH
TAG=$1
# App name
-APP=io.neovim.nvim
+APP=org.neovim.nvim
ROOT_DIR="$(git rev-parse --show-toplevel)"
APP_BUILD_DIR="$ROOT_DIR/build"
diff --git a/scripts/release.sh b/scripts/release.sh
index f7dd151efe..6d4a53a87e 100755
--- a/scripts/release.sh
+++ b/scripts/release.sh
@@ -12,7 +12,7 @@
# - CMakeLists.txt: Unset NVIM_VERSION_PRERELEASE
# - CMakeLists.txt: Unset NVIM_API_PRERELEASE
# - Create test/functional/fixtures/api_level_N.mpack
# - Add date and version to runtime/io.neovim.nvim.appdata.xml
# - Tag the commit.
# Create the "version bump" commit:
# - CMakeLists.txt: Set NVIM_VERSION_PRERELEASE to "-dev"
@@ -64,8 +64,8 @@ _do_release_commit() {
fi
$__sed -i.bk 's,(<releases>),\1\
- <release date="'"${__DATE}"'" version="'"${__VERSION}"'"/>,' runtime/io.neovim.nvim.appdata.xml
- git add runtime/io.neovim.nvim.appdata.xml
+ <release date="'"${__DATE}"'" version="'"${__VERSION}"'"/>,' runtime/org.neovim.nvim.appdata.xml
+ git add runtime/org.neovim.nvim.appdata.xml
if ! test "$ARG1" = '--use-current-commit' ; then
echo "Building changelog since ${__LAST_TAG}..."
@@ -81,7 +81,7 @@ _do_bump_commit() {
$__sed -i.bk 's/(NVIM_VERSION_PRERELEASE) ""/\1 "-dev"/' CMakeLists.txt
$__sed -i.bk 's/set\((NVIM_VERSION_PATCH) [[:digit:]]/set(\1 ?/' CMakeLists.txt
rm -f CMakeLists.txt.bk
- rm -f runtime/io.neovim.nvim.appdata.xml.bk
+ rm -f runtime/org.neovim.nvim.appdata.xml.bk
nvim +'/NVIM_VERSION' +1new +'exe "norm! iUpdate version numbers!!!"' \
-O CMakeLists.txt
@@ -12,7 +12,7 @@
# - CMakeLists.txt: Unset NVIM_API_PRERELEASE
# - Create test/functional/fixtures/api_level_N.mpack
-# - Add date and version to runtime/io.neovim.nvim.appdata.xml
+# - Add date and version to runtime/org.neovim.nvim.appdata.xml
# - Tag the commit.
# Create the "version bump" commit: